#!/usr/bin/env python

from matplotlib import pyplot
from matplotlib import ticker
from matplotlib import numpy

# This generates population graphs for the foreign resident population of Japan.
# The population is broken down by country.  Data is from Wikipedia.
#
# https://en.wikipedia.org/wiki/Demographics_of_Japan#Foreign_residents
#
# SVG files are produced using matplotlib.
#
# http://xmodulo.com/matplotlib-scientific-plotting-linux.html
#
# This file was written by Douglas Perkins.
# It is released under a Creative Commons 4.0 Attribution license.
# The resultant SVG file is released under the same license.
# 
# https://creativecommons.org/licenses/by/4.0/

data = [
("China",	665847),
("South Korea",	457772),
("Philippines",	229595),
("Brazil",	173437),
("Vietnam",	146956),
("Nepal",	54775),
("U.S.A.",	52271),
("Taiwan",	48723),
("Peru",	47721),
("Thailand",	45379),
]

countries = [country for (country, population) in data]
populations = [population for (country, population) in data]

listed_population = 0

for population in populations:
	listed_population += population

total_population = 2232189
unlisted_population = total_population - listed_population
populations.append(unlisted_population)
countries.append("Other")

# Make a pie graph.
pyplot.figure(num=1, figsize=(8,8))
pyplot.axes(aspect=1)
pyplot.title('2015 Foreign Resident Population of Japan')
pyplot.pie(populations, labels=countries, startangle=90)
pyplot.savefig('Nationality.Pie.svg', format='svg', bbox_inches='tight')
